@@ -240,7 +240,12 @@ class PreseemGrpcClient(object):
                              ('grpc.http2.max_pings_without_data', 0)]  # allow unlimited pings without data
                 if self.api_key:
                     call_creds = grpc.metadata_call_credentials(ApiKeyCallCredentials(self.api_key))
-                    ssl_creds = grpc.ssl_channel_credentials()
+                    try:
+                        with open('/etc/pki/tls/certs/ca-bundle.crt', 'rb') as f:
+                            ca_certs = f.read()
+                    except:  # not fedora?  use default built-in CA bundle
+                        ca_certs = None
+                    ssl_creds = grpc.ssl_channel_credentials(root_certificates=ca_certs)
                     channel_creds = grpc.composite_channel_credentials(ssl_creds, call_creds)
                     channel = grpc.secure_channel(dst, channel_creds, options=grpc_opts)
                 else:
