@@ -83,13 +83,13 @@ async def sync_preseem_model(preseem_model, nm_model, company_uuid, system=None,
 
         if aps and delete:  # only do this if we have APs for multi-system deployments
             for elem_id, elem in model_elems.items():
-                if elem_id not in bss_aps:
+                if elem_id not in bss_aps and not elem.inactive:
                     if verbose:
                         logging.info('Delete element: %s', elem)
                     await preseem_model.Element.Update(uuid=elem.uuid, company_uuid=elem.company_uuid, inactive=True)
 
             for site_id, site in model_sites.items():
-                if site_id not in bss_sites:
+                if site_id not in bss_sites and not site.inactive:
                     if verbose:
                         logging.info('Delete site: %s', site)
                     await preseem_model.Site.Update(uuid=site.uuid, company_uuid=site.company_uuid, inactive=True)
